<div class="resmng_nav">
    <ul class="nav nav-tabs">
        <li class="active"><a href="#resource" data-toggle="tab">{ln_resource}</a></li>
        <?php if ($this->rt_user->isAllowed('resmng', 'delete_from_trash') || $this->rt_user->isAllowed('resmng', 'recove_from_trash')) { ?>
            <li><a href="#deleted" data-toggle="tab">{ln_deleted}</a></li>
        <?php } ?>
    </ul>
    <div class="tab-content">
        <div class="tab-pane active noclose" id="resource">
            <div class="resmng_tree_menu" rel="set_0">
                {tree_menu}
            </div>
            <div id="context_menu_dialog" title="" style="display: none"></div>
        </div>
        <?php if ($this->rt_user->isAllowed('resmng', 'delete_from_trash') || $this->rt_user->isAllowed('resmng', 'recove_from_trash')) { ?>
            <div class="tab-pane noclose" id="deleted">
                <div class="resmng_tree_menu" rel="set_0">
                    {tree_menu_cart}
                </div>
            </div>
        <?php } ?>
    </div>
</div>
<div class="resmng_content">
    <ul id="tabs_nav" class="nav nav-tabs"></ul>
    <div id="tabs_content" class="tab-content"></div>
</div>
