<div class="control-group">
    <label class="control-label"><?= $this->lang->line('Page name in admin panel') ?>*</label>
    <div class="controls">
        <input type="text" name="page_data[admin_name]" value="<?= $item['admin_name'] ?>" required="required">
    </div>
</div>
<div class="control-group">
    <label class="control-label"><?= $this->lang->line('Page alias') ?>*</label>
    <div class="controls"><input type="text" name="page_data[alias]" value="<?= $item['alias'] ?>" required="required"></div>
</div>
<div class="control-group">
    <label class="control-label"><?= $this->lang->line('Active') ?></label>
    <div class="controls"><?= $this->rtgrid_field_callback->active('page_data[active]', $item['active']) ?></div>
</div>
<ul class="nav nav-tabs">
    <?php foreach ($langs as $k => $lang) : ?>
        <li <?= $k == 0 ? 'class="active"' : '' ?>>
            <a href="#seo_tab_<?= $lang->id_lan ?>" data-toggle="tab"><?= $this->lang->line('SEO') . ' ' . $lang->name ?></a>
        </li>
    <?php endforeach; ?>
</ul>
<div class="tab-content">
    <?php foreach ($langs as $k => $lang) : ?>
        <div class="tab-pane<?= $k == 0 ? ' active' : '' ?>" id="seo_tab_<?= $lang->id_lan ?>">
            <div class="control-group">
                <label class="control-label"><?= $this->lang->line('Title') ?></label>
                <div class="controls">
                    <input type="text" name="page_data[seo][<?= $lang->id_lan ?>][title]" value="<?= !empty($item['seo'][$lang->id_lan]) ? $item['seo'][$lang->id_lan]['title'] : '' ?>">
                </div>
            </div>
            <div class="control-group">
                <label class="control-label"><?= $this->lang->line('Keywords') ?></label>
                <div class="controls">
                    <textarea name="page_data[seo][<?= $lang->id_lan ?>][keywords]" class="span5" rows="5"><?= !empty($item['seo'][$lang->id_lan]) ? $item['seo'][$lang->id_lan]['keywords'] : '' ?></textarea>
                </div>
            </div>
            <div class="control-group">
                <label class="control-label"><?= $this->lang->line('Description') ?></label>
                <div class="controls">
                    <textarea name="page_data[seo][<?= $lang->id_lan ?>][desc]" class="span5" rows="5"><?= !empty($item['seo'][$lang->id_lan]) ? $item['seo'][$lang->id_lan]['desc'] : '' ?></textarea>
                </div>
            </div>
        </div>
    <?php endforeach; ?>
</div>