<?php

$lang['module_name'] = 'Менеджер ресурсів';

$lang['resmng_actions'] = array(
    'resmng_view' => 'Перегляд менеджера ресурсів',
    'private' => 'Перегляд елементів з обмеженою видимістю',
    'edite_private' => 'Зміна видимості',
    'create_element' => 'Створити елемент',
    'rename_element' => 'Перейменувати елемент',
    'remove_element' => 'Перемістити елемент',
    'delete_element' => 'Видалити елемент',
    'clone_element' => 'Клонувати елемент',
    'edit_page_content' => 'Редагувати вміст сторінки',
    'edit_page_template' => 'Редагувати шаблон сторінки',
    'edit_resource_content' => 'Редагувати вміст ресурсу',
    'delete_from_trash' => 'Видалити з кошика',
    'recove_from_trash' => 'Відновити з кошика'
);