<?php 

$lang['Page data'] = 'Данные страницы';
$lang['Page name in admin panel'] = 'Название в админ панеле';
$lang['Page alias'] = 'Псевдоним страницы';
$lang['Active'] = 'Отображать?';
$lang['SEO'] = 'SEO';
$lang['Title'] = 'Заглавие';
$lang['Keywords'] = 'Ключевые слова';
$lang['Description'] = 'Описание';

