<?php 

$lang['module_name'] = 'Менеджер ресурсов';

$lang['resmng_actions'] = array(
    'resmng_view' => 'Просмотр Менеджера ресурсов',
    'private' => 'Просмотр элементов с ограниченной видимостью',
    'edite_private' => 'Изменение видимости',
    'create_element' => 'Создать элемент',
    'rename_element' => 'Переименовать элемент',
    'remove_element' => 'Переместить элемент',
    'delete_element' => 'Удалить элемент',
    'clone_element' => 'Клонировать элемент',
    'edit_page_content' => 'Редактировать содержимое страницы',
    'edit_page_template' => 'Редактировать шаблон страницы',
    'edit_resource_content' => 'Редактировать содержимое ресурса',
    'delete_from_trash' => 'Удалить с корзины',
    'recove_from_trash' => 'Востановить с корзины'
);