<?php 

$lang['ln_resource'] = 'Ресурсы';
$lang['ln_deleted'] = 'Корзина';

$lang['item_refresh'] = 'Обновить';
$lang['item_rename'] = 'Переименовать';
$lang['item_create'] = 'Создать';
$lang['item_delete'] = 'Удалить';
$lang['item_clone'] = 'Клонировать';

$lang['item_recovery'] = 'Востановить';
$lang['item_clear'] = 'Очистить';