<table class="table">
    <thead>
        <tr>
            <th style="width: 15%">{ln_lang}</th>
            <th>{ln_content}</th>
        </tr>
    </thead>
    <tbody>
        {item}
        <tr>
            <td>
                <p>{name}</p>
            </td>
            <td>
                <textarea name="content[{id_lan}]" rows="15" style="width: 95%">{content}</textarea>
            </td>
        </tr>
        {/item}
    </tbody>
</table>

