<ul id="resmng_contextmenu_tree_cart" style="display:none">
    <?php if ($this->rt_user->isAllowed('resmng', 'recove_from_trash')) { ?>
        <li><a href="#" onclick="treeMenuTrashAction(1, '{item_recovery}')">{item_recovery}</a></li>
    <?php } ?>

    <?php if ($this->rt_user->isAllowed('resmng', 'delete_from_trash')) { ?>
        <li><a href="#" onclick="treeMenuTrashAction(2, '{item_clear}')">{item_clear}</a></li>
    <?php } ?>
</ul>